[![PyPI](https://badgen.net/pypi/v/PySCSS)](https://pypi.org/project/PySCSS/)
[![Build Status](https://github.com/PennyWieser/PySCSS/actions/workflows/main.yml/badge.svg?branch=main)](https://github.com/PennyWieser/PySCSS/actions/workflows/main.yml)
[![codecov](https://codecov.io/gh/PennyWieser/PySCSS/branch/main/graph/badge.svg)](https://codecov.io/gh/PennyWieser/PySCSS/branch/main)

A python tool for PySCSSometry.
Examples and documentation available at
https://PySCSS.readthedocs.io/en/latest/index.html
Still a work in progress, contact Penny Wieser with questions.